==> haskell-jwt-0.7.2-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-jwt.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: jwt
version: 0.7.2
id: jwt-0.7.2-AAvzBpVU6LX17bWFkQGDwR
key: jwt-0.7.2-AAvzBpVU6LX17bWFkQGDwR
license: MIT
maintainer: stefan@saasen.me
homepage: https://bitbucket.org/ssaasen/haskell-jwt
synopsis: JSON Web Token (JWT) decoding and encoding
description:
    JSON Web Token (JWT) is a compact URL-safe means of representing claims to be transferred between two parties.
    .
    To get started, see the documentation for the "Web.JWT" module.
category: Web
author: Stefan Saasen
exposed: True
indefinite: False
exposed-modules:
    Web.JWT
hidden-modules: Data.Text.Extended Data.ByteString.Extended
abi: a7da8ea7831c1a96b08cede50b898ba5
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/jwt-0.7.2
library-dirs: /usr/lib/ghc-8.2.1/site-local/jwt-0.7.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.1/jwt-0.7.2
hs-libraries: HSjwt-0.7.2-AAvzBpVU6LX17bWFkQGDwR
depends:
    base-4.10.0.0 cryptonite-0.24-1eRB8onf2x1HH5rI2M7djb
    memory-0.14.6-HxsAJFqa809Bv6WJsrwqao bytestring-0.10.8.2
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
    aeson-1.2.1.0-4B0AgiChYBfAqHGTNuDPfn containers-0.5.10.2
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN
    scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q
    data-default-0.7.1.1-7D2kYbZAPZs3NL2w6K0r5J
    http-types-0.9.1-4bB5vMj0wc7H0s2DJoYpPW time-1.8.0.2
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi
    semigroups-0.18.3-6KPIVJcHqOOBHjBl8WA5LP
    network-uri-2.6.1.0-4GXMsZ4PWr49y3TK4YgSYK
abi-depends: base-4.10.0.0=835a16347ec1b210054efd02671c29ee
             cryptonite-0.24-1eRB8onf2x1HH5rI2M7djb=d02ab198c5c49165db40ebdbd565d8e9
             memory-0.14.6-HxsAJFqa809Bv6WJsrwqao=5aa9d77910d6888267534eeffbc4b2ec
             bytestring-0.10.8.2=590a7a3c0bdcf7a6a59d8c8ef548a44a
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=9217a19661a41b462c62d1a4bdf2e9b1
             aeson-1.2.1.0-4B0AgiChYBfAqHGTNuDPfn=de27a328e189bca785104a080be3af69
             containers-0.5.10.2=dd4e66fa9ac268f47a15786f1100b042
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=f561664cdb04511e569f0d44c9086d8e
             scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q=4e1885ea3bd9d96a68a990bad22946fe
             data-default-0.7.1.1-7D2kYbZAPZs3NL2w6K0r5J=f7324150b92035ce2f13f55c36f08ab4
             http-types-0.9.1-4bB5vMj0wc7H0s2DJoYpPW=b05755a8562dd13d7429852f04c3b73b
             time-1.8.0.2=e9c7416c5b79f57513fe11898c3d9f95
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=23f6c0fe109d2ea8c2d28bae9257ae6c
             semigroups-0.18.3-6KPIVJcHqOOBHjBl8WA5LP=f833729171d8aeedacf984b736ec248c
             network-uri-2.6.1.0-4GXMsZ4PWr49y3TK4YgSYK=0d8dbc66a8173770b7f27b72bc5a4600
haddock-interfaces: /usr/share/doc/haskell-jwt/html/jwt.haddock
haddock-html: /usr/share/doc/haskell-jwt/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-jwt-0.7.2-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-jwt.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: jwt
version: 0.7.2
id: jwt-0.7.2-HqTE32h9N6K1nCEM0xqX15
key: jwt-0.7.2-HqTE32h9N6K1nCEM0xqX15
license: MIT
maintainer: stefan@saasen.me
homepage: https://bitbucket.org/ssaasen/haskell-jwt
synopsis: JSON Web Token (JWT) decoding and encoding
description:
    JSON Web Token (JWT) is a compact URL-safe means of representing claims to be transferred between two parties.
    .
    To get started, see the documentation for the "Web.JWT" module.
category: Web
author: Stefan Saasen
exposed: True
indefinite: False
exposed-modules:
    Web.JWT
hidden-modules: Data.Text.Extended Data.ByteString.Extended
abi: 0f0aea5d99a27dc9c0f99aa6ddba1f33
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/jwt-0.7.2
library-dirs: /usr/lib/ghc-8.2.1/site-local/jwt-0.7.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.1/jwt-0.7.2
hs-libraries: HSjwt-0.7.2-HqTE32h9N6K1nCEM0xqX15
depends:
    base-4.10.0.0 cryptonite-0.24-8TqkyTTvSG93llKG92zgyl
    memory-0.14.7-CZTdOBCJoah1c0c3vYdFwT bytestring-0.10.8.2
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
    aeson-1.2.1.0-4B0AgiChYBfAqHGTNuDPfn containers-0.5.10.2
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN
    scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q
    data-default-0.7.1.1-7D2kYbZAPZs3NL2w6K0r5J
    http-types-0.9.1-4bB5vMj0wc7H0s2DJoYpPW time-1.8.0.2
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi
    semigroups-0.18.3-6KPIVJcHqOOBHjBl8WA5LP
    network-uri-2.6.1.0-4GXMsZ4PWr49y3TK4YgSYK
abi-depends: base-4.10.0.0=835a16347ec1b210054efd02671c29ee
             cryptonite-0.24-8TqkyTTvSG93llKG92zgyl=6740aec73109c5ddadb2db4ccab3ea83
             memory-0.14.7-CZTdOBCJoah1c0c3vYdFwT=2e00c0fd9579ae3612d6b6e3f4f8dc53
             bytestring-0.10.8.2=590a7a3c0bdcf7a6a59d8c8ef548a44a
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=9217a19661a41b462c62d1a4bdf2e9b1
             aeson-1.2.1.0-4B0AgiChYBfAqHGTNuDPfn=de27a328e189bca785104a080be3af69
             containers-0.5.10.2=dd4e66fa9ac268f47a15786f1100b042
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=f561664cdb04511e569f0d44c9086d8e
             scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q=4e1885ea3bd9d96a68a990bad22946fe
             data-default-0.7.1.1-7D2kYbZAPZs3NL2w6K0r5J=f7324150b92035ce2f13f55c36f08ab4
             http-types-0.9.1-4bB5vMj0wc7H0s2DJoYpPW=b05755a8562dd13d7429852f04c3b73b
             time-1.8.0.2=e9c7416c5b79f57513fe11898c3d9f95
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=23f6c0fe109d2ea8c2d28bae9257ae6c
             semigroups-0.18.3-6KPIVJcHqOOBHjBl8WA5LP=f833729171d8aeedacf984b736ec248c
             network-uri-2.6.1.0-4GXMsZ4PWr49y3TK4YgSYK=0d8dbc66a8173770b7f27b72bc5a4600
haddock-interfaces: /usr/share/doc/haskell-jwt/html/jwt.haddock
haddock-html: /usr/share/doc/haskell-jwt/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
